==> owncloud-6.0.4.tgz: owncloud/apps/updater/l10n/ru.php <==
<?php $TRANSLATIONS = array(
"Checking your installation..." => "Проверяется Ваша установка...",
"Upgrade is not possible. Make sure that your webserver has write access to the following files and directories:" => "Обновление невозможно. Проверьте, что Ваш вебсервер имеет права на запись следующих файлов и директорий:",
"Version not found" => "Версия не найдена",
"Upgrade is not possible. Your webserver has not enough permissions to remove the following directory:" => "Обновление невозможно. Ваш вебсервер не имеет достаточно прав на удаление следующей директории:",
"Update permissions on this directory and its content or remove it manually first." => "Обновите разрешения на эту дерикторию и её содержимое или удалите её вручную для начала.",
"Downloading package..." => "Скачивание пакета...",
"Unable to fetch package" => "Не удалось извлечь пакет",
"Creating backup..." => "Создание резервной копии...",
"Here is your backup: " => "Вот Ваша резервная копия:",
"Failed to create backup" => "Не удалось создать резервную копию",
"Moving files..." => "Перемещение файлов...",
"All done. Click to the link below to start database upgrade." => "Всё закончено. Нажмите ссылку ниже для начала обновления базы данных.",
"Update failed" => "Обновление не удалось",
"The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>." => "При обновлении произошла ошибка. Пожалуйста сообщите об этой ошибке <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud сообществу</a>.",
"Update Center" => "Центр обновлений",
"Backup Management" => "Управление резервным копированием",
"Update" => "Обновить",
"Backup directory" => "Директория резервных копий",
"Backup" => "Резервная копия",
"Done on" => "Готово на",
"Download" => "Скачать",
"Delete" => "Удалить",
"No backups found" => "Резервных копий не найдено"
);

==> owncloud-7.0.4.tgz: owncloud/apps/updater/l10n/ru.php <==
<?php
$TRANSLATIONS = array(
"Checking your installation..." => "Проверяется Ваша установка...",
"Upgrade is not possible. Make sure that your webserver has write access to the following files and directories:" => "Обновление невозможно. Проверьте, что Ваш вебсервер имеет права на запись следующих файлов и директорий:",
"Version not found" => "Версия не найдена",
"Upgrade is not possible. Your webserver has not enough permissions to remove the following directory:" => "Обновление невозможно. Ваш вебсервер не имеет достаточно прав на удаление следующей директории:",
"Update permissions on this directory and its content or remove it manually first." => "Обновите разрешения на эту дерикторию и её содержимое или удалите её вручную для начала.",
"Downloading package..." => "Скачивание пакета...",
"Unable to fetch package" => "Не удалось извлечь пакет",
"Creating backup..." => "Создание резервной копии...",
"Here is your backup: " => "Вот Ваша резервная копия:",
"Failed to create backup" => "Не удалось создать резервную копию",
"Moving files..." => "Перемещение файлов...",
"All done. Click to the link below to start database upgrade." => "Всё закончено. Нажмите ссылку ниже для начала обновления базы данных.",
"Update failed" => "Обновление не удалось",
"The update was unsuccessful. Please check logs at admin page and report this issue to the <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>." => "Обновление не удалось. Пожалуйста, проверьте журналы на странице администратора и сообщите об этой проблеме <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">сообществу ownCloud</a>.",
"Proceed" => "продолжить",
"Updater" => "Обновление",
"Update Center" => "Центр обновлений",
"Backup Management" => "Управление резервным копированием",
"Update" => "Обновить",
"Backup directory" => "Директория резервных копий",
"Backup" => "Резервная копия",
"Done on" => "Готово на",
"Download" => "Скачать",
"Delete" => "Удалить",
"No backups found" => "Резервных копий не найдено"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
